import { useState } from "react";
import { useForm, router } from '@inertiajs/react';
import toast, { Toaster } from 'react-hot-toast';

export default function ToggleSwitch({ instance }) {
    const [isChecked, setIsChecked] = useState(instance?.is_principal);
    const { post: post } = useForm({ id: instance?.id });

    const handleToggle = (e) => {
        setIsChecked(!isChecked);

        e.preventDefault();

        post(route('whatsapp.isPrincipal', instance?.id), {
            onSuccess: () => {
                toast.success('Instância definida como padrão com sucesso!');
                router.reload();
            },
            onError: (errors) => {
                toast.error(errors?.error || 'Ocorreu um erro inesperado.');
            },
        });
    };

    return (
        <label className="flex items-center cursor-pointer mt-3">
            <div className="relative">
                <input type="checkbox" checked={isChecked} onChange={handleToggle} className="sr-only" />

                {/* Fundo do switch */}
                <div className={`block w-8 h-[.728rem] rounded-full transition-colors duration-300 ${isChecked ? "bg-primary" : "bg-danger"}`}></div>

                {/* Indicador deslizante */}
                <div className={`absolute top-0 left-1 w-3 h-3 bg-text-white rounded-full transform transition-transform duration-300 ${isChecked ? "translate-x-3" : "translate-x-0"}`}></div>
            </div>
            <span className="ml-3 text-text-primary text-[.7rem]">Definir como padrão</span>
        </label>
    );
}
